@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver;
 # ABSTRACT: Perl Neo4j driver for Bolt and HTTP
-$Neo4j::Driver::VERSION = '0.20';
+$Neo4j::Driver::VERSION = '0.21';
 
 use Carp qw(croak);
 
@@ -29,6 +29,7 @@ my %OPTIONS = (
 	ca_file => 'tls_ca',
 	cypher_filter => 'cypher_filter',
 	cypher_types => 'cypher_types',
+	jolt => 'jolt',
 	net_module => 'net_module',
 	timeout => 'http_timeout',
 	tls => 'tls',
@@ -44,6 +45,7 @@ my %DEFAULTS = (
 		temporal => 'Neo4j::Driver::Type::Temporal',
 	},
 	die_on_error => 1,
+	jolt => 0,
 );
 
 
@@ -167,7 +169,7 @@ Neo4j::Driver - Perl Neo4j driver for Bolt and HTTP
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -201,12 +203,40 @@ existing L<REST::Neo4p> module does. Nor does it offer any L<DBI>
 integration. However, it avoids the legacy C<cypher> endpoint,
 assuring compatibility with Neo4j versions 2.3, 3.x and 4.x.
 
-The HTTP and Bolt protocols are supported for connecting to Neo4j.
-Bolt requires installing the XS module L<Neo4j::Bolt>. Using Bolt
-is much faster than HTTP, but at time of this writing the
-L<libneo4j-client|https://neo4j-client.net/#libneo4j-client> backend
-library that L<Neo4j::Bolt> uses to connect to the database server
-only supports Neo4j version 3.x.
+Two different network protocols exist for connecting to Neo4j.
+By default, Neo4j servers offer both, but this can be changed
+in F<neo4j.conf> for each server; see
+L<"Configure connectors" in the Neo4j Operations Manual|https://neo4j.com/docs/operations-manual/current/configuration/connectors/>.
+
+=over
+
+=item Bolt
+
+Bolt is a Neo4j proprietary, binary protocol, available with
+S<Neo4j 3.0> and newer. Bolt communication may be encrypted or
+unencrypted. Because Bolt is faster than HTTP, it is generally
+the recommended protocol. However, support for it may be
+lagging after major updates to Neo4j.
+
+This driver supports Bolt, but doesn't bundle the necessary XS
+packages. You will need to install L<Neo4j::Bolt> separately
+to enable Bolt.
+
+=item HTTP / HTTPS
+
+Support for HTTP is built into this driver, so it is always
+available. HTTP is still fast enough for many use cases and
+works even in a "Pure Perl" environment. It may also be
+quicker than Bolt to add support for future changes in Neo4j.
+
+The driver also supports encrypted communication using HTTPS,
+but doesn't bundle the necessary packages. You will need to
+install L<LWP::Protocol::https> separately to enable HTTPS.
+
+=back
+
+The protocol is automatically chosen based on the URI scheme.
+See L</"new"> for details.
 
 B<As of version 0.13, the interface of this software may be
 considered stable.>
@@ -267,7 +297,8 @@ including server URIs, credentials and other configuration.
 
 The URI passed to this method determines the type of driver created. 
 The C<http>, C<https>, and C<bolt> URI schemes are supported.
-Use of C<bolt> URIs requires L<Neo4j::Bolt> to be installed.
+Use of C<bolt> URIs requires L<Neo4j::Bolt> to be installed; use
+of C<https> URIs requires L<LWP::Protocol::https> to be installed.
 
 If a part of the URI or even the entire URI is missing, suitable
 default values will be substituted. In particular, the host name
@@ -315,6 +346,46 @@ This feature is currently undergoing testing. Until it becomes
 stable, please continue to use HTTP with S<Neo4j 4> in production
 environments.
 
+=head2 Jolt
+
+ $d->config(jolt => undef);  # let the server decide
+ $d->config(jolt => 0);      # accept only JSON (the default)
+ $d->config(jolt => 1);      # accept only Jolt
+
+There is experimental support for Neo4j HTTP responses that use the
+L<Jolt|https://neo4j.com/docs/http-api/4.2/actions/result-format/#_jolt>
+format (JSON Bolt). This new response format will soon become this
+driver's default for HTTP connections. For now, you'll have to
+request it explicitly using the C<jolt> config option.
+
+If you use the scalars C<'sparse'> or C<'strict'> instead of just
+C<1>, the driver will request that particular Jolt mode from the
+server. However, there is no advantage to manually selecting one
+of these modes. This feature is for testing purposes only.
+
+=head2 Custom networking modules
+
+ use Local::MyNetworkAgent;
+ $driver->config(net_module => 'Local::MyNetworkAgent');
+
+The module to be used for network communication may be specified
+using the C<net_module> config option. The specified module must
+implement the API described in L<Neo4j::Driver::Net/"EXTENSIONS">.
+Your code must C<use> or C<require> the module it specifies here.
+
+By default, the driver will try to auto-detect a suitable module.
+This will currently always result in the driver's built-in modules
+being used. Alternatively, you may specify the empty string to ask
+for the built-in modules explicitly, which will disable
+auto-detection.
+
+ $driver->config(net_module => undef);  # auto-detect (the default)
+ $driver->config(net_module => '');     # use the built-in modules
+
+This config option is experimental because the API for custom
+networking modules is still evolving. See L<Neo4j::Driver::Net>
+for details.
+
 =head2 Parameter syntax conversion
 
  $driver->config(cypher_filter => 'params');
@@ -364,6 +435,10 @@ Neo4j::Driver. Reading or modifying their values is unsupported
 and discouraged because it makes your code prone to fail when any
 internals change in the implementation of Neo4j::Driver.
 
+The C<cypher_types> config option will soon be deprecated and
+eventually be removed. The C<net_module> option offers the same
+functionality and more (albeit somewhat less conveniently).
+
 =head1 CONFIGURATION OPTIONS
 
 L<Neo4j::Driver> implements the following configuration options.
