@@ -5,8 +5,9 @@ use utf8;
 
 package Neo4j::Driver::Type::Path;
 # ABSTRACT: Directed sequence of relationships between two nodes
-$Neo4j::Driver::Type::Path::VERSION = '0.20';
+$Neo4j::Driver::Type::Path::VERSION = '0.21';
 
+use parent 'Neo4j::Types::Path';
 use overload '@{}' => \&_array, fallback => 1;
 
 use Carp qw(croak);
@@ -77,7 +78,7 @@ Neo4j::Driver::Type::Path - Directed sequence of relationships between two nodes
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -100,39 +101,26 @@ start and the end of the path.
 
 =head1 METHODS
 
-L<Neo4j::Driver::Type::Path> implements the following methods.
+L<Neo4j::Driver::Type::Path> inherits all methods from
+L<Neo4j::Types::Path>.
 
 =head2 elements
 
  @all = $path->elements;
 
-Return the path as a list alternating between nodes
-and relationships in path sequence order.
+See L<Neo4j::Types::Path/"elements">.
 
 =head2 nodes
 
  @nodes = $path->nodes;
 
-Return all L<nodes|Neo4j::Driver::Type::Node> of this path.
-
-The start node of this path is the first node in the array this method
-returns, the end node is the last one.
-
- @nodes = $path->nodes;
- $start_node = $nodes[0];
- $end_node   = $nodes[@nodes - 1];
+See L<Neo4j::Types::Path/"nodes">.
 
 =head2 relationships
 
  @rels = $path->relationships;
 
-Return all L<relationships|Neo4j::Driver::Type::Relationship>
-of this path.
-
-The length of a path is defined as the number of relationships.
-
- @rels = $path->relationships;
- $length = scalar @rels;
+See L<Neo4j::Types::Path/"relationships">.
 
 =head1 EXPERIMENTAL FEATURES
 
@@ -152,7 +140,7 @@ C<die> if called in scalar context.
 
 =head1 BUGS
 
-When paths are returned via HTTP, the objects accessible via
+When paths are returned via HTTP JSON, the objects accessible via
 C<elements()>, C<nodes()>, and C<relationships()> lack meta data for
 their labels and types. This is due to an issue in the Neo4j server.
 
@@ -162,6 +150,8 @@ their labels and types. This is due to an issue in the Neo4j server.
 
 =item * L<Neo4j::Driver>
 
+=item * L<Neo4j::Types::Path>
+
 =item * Equivalent documentation for the official Neo4j drivers:
 L<Path (Java)|https://neo4j.com/docs/api/java-driver/current/index.html?org/neo4j/driver/types/Path.html>
 
