@@ -5,8 +5,9 @@ use utf8;
 
 package Neo4j::Driver::Type::Relationship;
 # ABSTRACT: Describes a relationship from a Neo4j graph
-$Neo4j::Driver::Type::Relationship::VERSION = '0.20';
+$Neo4j::Driver::Type::Relationship::VERSION = '0.21';
 
+use parent 'Neo4j::Types::Relationship';
 use overload '%{}' => \&_hash, fallback => 1;
 
 
@@ -91,7 +92,7 @@ Neo4j::Driver::Type::Relationship - Describes a relationship from a Neo4j graph
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -122,53 +123,45 @@ IDs.
 
 =head1 METHODS
 
-L<Neo4j::Driver::Type::Relationship> implements the following methods.
+L<Neo4j::Driver::Type::Relationship> inherits all methods from
+L<Neo4j::Types::Relationship>.
 
 =head2 get
 
  $value = $relationship->get('property_key');
 
-Retrieve the value of this relationship's property with the given key.
-If no such key exists, return C<undef>.
+See L<Neo4j::Types::Relationship/"get">.
 
 =head2 id
 
  $id = $relationship->id;
 
-Return a unique ID for this relationship.
-
-In the Neo4j Driver API, entity IDs are only guaranteed to remain
-stable for the duration of the current session. Although in practice
-server versions at least up to and including Neo4j 3.5 may appear
-to use persistent IDs, your code should not depend upon that.
-
-A relationship with the ID C<0> may exist.
-Nodes and relationships do not share the same ID space.
+See L<Neo4j::Types::Relationship/"id">.
 
 =head2 properties
 
  $hashref = $relationship->properties;
  $value = $hashref->{property_key};
 
-Return all properties of this relationship as a hash reference.
+See L<Neo4j::Types::Relationship/"properties">.
 
 =head2 start_id
 
  $id = $relationship->start_id;
 
-Return the ID of the node where this relationship starts.
+See L<Neo4j::Types::Relationship/"start_id">.
 
 =head2 end_id
 
  $id = $relationship->end_id;
 
-Return the ID of the node where this relationship ends.
+See L<Neo4j::Types::Relationship/"end_id">.
 
 =head2 type
 
  $type = $relationship->type;
 
-Return the type of this relationship.
+See L<Neo4j::Types::Relationship/"type">.
 
 =head1 EXPERIMENTAL FEATURES
 
@@ -197,7 +190,7 @@ returned by this method.
 The value of properties named C<_meta>, C<_relationship>, C<_start>,
 C<_end>, or C<_type> may not be returned correctly.
 
-When using HTTP, the C<type> of relationships that are returned as
+When using HTTP JSON, the C<type> of relationships that are returned as
 part of a L<Neo4j::Driver::Type::Path> is unavailable, because that
 information is not currently reported by the Neo4j server. C<undef>
 is returned instead.
@@ -208,6 +201,8 @@ is returned instead.
 
 =item * L<Neo4j::Driver>
 
+=item * L<Neo4j::Types::Relationship>
+
 =item * Equivalent documentation for the official Neo4j drivers:
 L<Relationship (Java)|https://neo4j.com/docs/api/java-driver/current/index.html?org/neo4j/driver/types/Relationship.html>,
 L<Relationship (Python)|https://neo4j.com/docs/api/python-driver/current/api.html#relationship>
